==> ejc-credentials-impl-3.0.0-20220608.025626-40-sources.jar: com/ejianc/certify/vo/LendresHVO.java <==
package com.ejianc.certify.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 公司借证归还-表头
 * 
 * @author generator
 * 
 */
public class LendresHVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long approver; // 审批人
    private String taudittime; // 审批时间
    private String vapprovenote; // 审批附言
    private Integer billState; // 单据状态
    private Long pkBilltype; // 单据类型
    private Date ts; // 时间戳
    private String vbusitype; // 业务类型(1-实物归还 2-使用归还)
    private String pkGroup; // 集团
    private Long pkOrg; // 发起人组织
    private Long pkDept; // 发起人部门
    private String vbillcode; // 单据编号
    private String dbilldate; // 单据日期
    private String vmemo; // 备注
    private Long pkFqr; // 发起人
    private String pkCorpcertify; // 原借用单(支持表头表体多选，此字段以逗号分割)
    private String isthgh; // 是否借用替换归还
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 

    private String orgName; //
    private String fqrName; //
    private String pjrName; //
    private String deptName; //
    private String busitypeName; //
    private String projectName; //
    private String pmProjectName; //
    private String projectJlbName; //
    private String billStatusName; //
    private String thghName; //

    private List<LendresBVO> lendresBVOList = new ArrayList<>();

    public List<LendresBVO> getLendresBVOList() {
        return lendresBVOList;
    }

    public void setLendresBVOList(List<LendresBVO> lendresBVOList) {
        this.lendresBVOList = lendresBVOList;
    }

    public String getThghName() {
        return thghName;
    }

    public void setThghName(String thghName) {
        this.thghName = thghName;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getFqrName() {
        return fqrName;
    }

    public void setFqrName(String fqrName) {
        this.fqrName = fqrName;
    }

    public String getPjrName() {
        return pjrName;
    }

    public void setPjrName(String pjrName) {
        this.pjrName = pjrName;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }

    public String getBusitypeName() {
        return busitypeName;
    }

    public void setBusitypeName(String busitypeName) {
        this.busitypeName = busitypeName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getPmProjectName() {
        return pmProjectName;
    }

    public void setPmProjectName(String pmProjectName) {
        this.pmProjectName = pmProjectName;
    }

    public String getProjectJlbName() {
        return projectJlbName;
    }

    public void setProjectJlbName(String projectJlbName) {
        this.projectJlbName = projectJlbName;
    }

    public String getBillStatusName() {
        return billStatusName;
    }

    public void setBillStatusName(String billStatusName) {
        this.billStatusName = billStatusName;
    }

    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    @ReferSerialTransfer(referCode = "billType")
    public Long getPkBilltype() {
        return pkBilltype;
    }
    @ReferDeserialTransfer
    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkOrg() {
        return pkOrg;
    }
    @ReferDeserialTransfer
    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDept() {
        return pkDept;
    }
    @ReferDeserialTransfer
    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }

    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkFqr() {
        return pkFqr;
    }
    @ReferDeserialTransfer
    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }

    public String getPkCorpcertify() {
        return pkCorpcertify;
    }
    public void setPkCorpcertify(String pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }

    public String getIsthgh() {
        return isthgh;
    }

    public void setIsthgh(String isthgh) {
        this.isthgh = isthgh;
    }

    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220614.031901-51-sources.jar: com/ejianc/certify/vo/LendresHVO.java <==
package com.ejianc.certify.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 公司借证归还-表头
 * 
 * @author generator
 * 
 */
public class LendresHVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long approver; // 审批人
    private String taudittime; // 审批时间
    private String vapprovenote; // 审批附言
    private Integer billState; // 单据状态
    private Long pkBilltype; // 单据类型
    private Date ts; // 时间戳
    private String vbusitype; // 业务类型(1-实物归还 2-使用归还)
    private String pkGroup; // 集团
    private Long pkOrg; // 发起人组织
    private Long pkDept; // 发起人部门
    private String vbillcode; // 单据编号
    private String dbilldate; // 单据日期
    private String vmemo; // 备注
    private Long pkFqr; // 发起人
    private String isthgh; // 是否借用替换归还
    private String vdef1; // 
    private String vdef10; // 
    private String vdef2; // 
    private String vdef3; // 
    private String vdef4; // 
    private String vdef5; // 
    private String vdef6; // 
    private String vdef7; // 
    private String vdef8; // 
    private String vdef9; // 

    private String orgName; //
    private String fqrName; //
    private String pjrName; //
    private String deptName; //
    private String busitypeName; //
    private String projectName; //
    private String pmProjectName; //
    private String projectJlbName; //
    private String billStatusName; //
    private String thghName; //

    private String pkCorpcertify; // 原借用单(支持表头表体多选，此字段以逗号分割)

    private List<LendresEVO> lendresEVOList = new ArrayList<>();

    private List<LendresBVO> lendresBVOList = new ArrayList<>();

    public List<LendresEVO> getLendresEVOList() {
        return lendresEVOList;
    }

    public void setLendresEVOList(List<LendresEVO> lendresEVOList) {
        this.lendresEVOList = lendresEVOList;
    }

    public List<LendresBVO> getLendresBVOList() {
        return lendresBVOList;
    }

    public void setLendresBVOList(List<LendresBVO> lendresBVOList) {
        this.lendresBVOList = lendresBVOList;
    }

    public String getThghName() {
        return thghName;
    }

    public void setThghName(String thghName) {
        this.thghName = thghName;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getFqrName() {
        return fqrName;
    }

    public void setFqrName(String fqrName) {
        this.fqrName = fqrName;
    }

    public String getPjrName() {
        return pjrName;
    }

    public void setPjrName(String pjrName) {
        this.pjrName = pjrName;
    }

    public String getDeptName() {
        return deptName;
    }

    public void setDeptName(String deptName) {
        this.deptName = deptName;
    }

    public String getBusitypeName() {
        return busitypeName;
    }

    public void setBusitypeName(String busitypeName) {
        this.busitypeName = busitypeName;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getPmProjectName() {
        return pmProjectName;
    }

    public void setPmProjectName(String pmProjectName) {
        this.pmProjectName = pmProjectName;
    }

    public String getProjectJlbName() {
        return projectJlbName;
    }

    public void setProjectJlbName(String projectJlbName) {
        this.projectJlbName = projectJlbName;
    }

    public String getBillStatusName() {
        return billStatusName;
    }

    public void setBillStatusName(String billStatusName) {
        this.billStatusName = billStatusName;
    }

    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    @ReferSerialTransfer(referCode = "billType")
    public Long getPkBilltype() {
        return pkBilltype;
    }
    @ReferDeserialTransfer
    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }

    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkOrg() {
        return pkOrg;
    }
    @ReferDeserialTransfer
    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }

    @ReferSerialTransfer(referCode = "idm-org")
    public Long getPkDept() {
        return pkDept;
    }
    @ReferDeserialTransfer
    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }

    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }

    @ReferSerialTransfer(referCode = "idm-user")
    public Long getPkFqr() {
        return pkFqr;
    }
    @ReferDeserialTransfer
    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }

    public String getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(String pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }

    public String getIsthgh() {
        return isthgh;
    }

    public void setIsthgh(String isthgh) {
        this.isthgh = isthgh;
    }

    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}
